==> ckan-2.0.tar.gz: ckan-2.0/ckan/public/base/i18n/ca.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ca",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Ha tingut lloc un error"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Teniu tota la seguretat per a dur a terme aquesta acció?"
  ],
  "Cancel": [
    null,
    "Cancel·lar"
  ],
  "Confirm": [
    null,
    "Confirma"
  ],
  "Edit": [
    null,
    "Editar"
  ],
  "Failed to load data API information": [
    null,
    "Ha fallat la càrrega d'informació de l'API"
  ],
  "Follow": [
    null,
    "Seguir"
  ],
  "Hide": [
    null,
    "Oculta"
  ],
  "Input is too short, must be at least one character": [
    null,
    "L'entrada de dades és massa curta, almenys ha de tenir un caràcter"
  ],
  "Loading...": [
    null,
    "Carregant..."
  ],
  "No matches found": [
    null,
    "No s'ha trobat coincidències"
  ],
  "Please Confirm Action": [
    null,
    "Acció de confirmació"
  ],
  "Resource uploaded": [
    null,
    "El recurs s'ha carregat"
  ],
  "Show more": [
    null,
    "Mostra més"
  ],
  "Start typing…": [
    null,
    "Comenceu a escriure..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Aquest formulari conté modificacions no desades"
  ],
  "There is no API data to load for this resource": [
    null,
    "No hi ha dades de l'API per a carregar-les en aquest recurs"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "No es pot autenticar la càrrega"
  ],
  "Unable to get data for uploaded file": [
    null,
    "No es pot obtenir les dades per a l'arxiu carregat"
  ],
  "Unable to upload file": [
    null,
    "No es pot carregar l'arxiu"
  ],
  "Unfollow": [
    null,
    "Deixar de seguir"
  ],
  "Upload a file": [
    null,
    "Carregar un arxiu"
  ],
  "show less": [
    null,
    "mostra menys"
  ],
  "show more": [
    null,
    "mostra més"
  ]
}

==> ckan-2.1.1.tar.gz: ckan-2.1.1/ckan/public/base/i18n/ca.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ca",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Ha tingut lloc un error"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Teniu tota la seguretat per a dur a terme aquesta acció?"
  ],
  "Cancel": [
    null,
    "Cancel·lar"
  ],
  "Confirm": [
    null,
    "Confirma"
  ],
  "Edit": [
    null,
    "Editar"
  ],
  "Failed to load data API information": [
    null,
    "Ha fallat la càrrega d'informació de l'API"
  ],
  "Follow": [
    null,
    "Seguir"
  ],
  "Hide": [
    null,
    "Oculta"
  ],
  "Input is too short, must be at least one character": [
    null,
    "L'entrada de dades és massa curta, almenys ha de tenir un caràcter"
  ],
  "Loading...": [
    null,
    "Carregant..."
  ],
  "No matches found": [
    null,
    "No s'ha trobat coincidències"
  ],
  "Please Confirm Action": [
    null,
    "Acció de confirmació"
  ],
  "Resource uploaded": [
    null,
    "El recurs s'ha carregat"
  ],
  "Show more": [
    null,
    "Mostra més"
  ],
  "Start typing…": [
    null,
    "Comenceu a escriure..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Aquest formulari conté modificacions no desades"
  ],
  "There is no API data to load for this resource": [
    null,
    "No hi ha dades de l'API per a carregar-les en aquest recurs"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "No es pot autenticar la càrrega"
  ],
  "Unable to get data for uploaded file": [
    null,
    "No es pot obtenir les dades per a l'arxiu carregat"
  ],
  "Unable to upload file": [
    null,
    "No es pot carregar l'arxiu"
  ],
  "Unfollow": [
    null,
    "Deixar de seguir"
  ],
  "Upload a file": [
    null,
    "Carregar un arxiu"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Esteu pujant un arxiu. Esteu segurs que voleu marxar de la pàgina i aturar la pujada?"
  ],
  "show less": [
    null,
    "mostra menys"
  ],
  "show more": [
    null,
    "mostra més"
  ]
}
